==> nextcloud-13.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/settings/l10n/bs.js <==
OC.L10N.register(
    "settings",
    {
    "Wrong password" : "Pogrešna lozinka",
    "Saved" : "Spremljeno",
    "No user supplied" : "Nijedan korisnik nije dostavljen",
    "Unable to change password" : "Promjena lozinke nije moguća",
    "Authentication error" : "Grešna autentifikacije",
    "Wrong admin recovery password. Please check the password and try again." : "Pogrešna admin lozinka za povratak. Molim provjerite lozinku i pokušajte ponovno.",
    "Group already exists." : "Grupa već postoji.",
    "Unable to add group." : "Nemoguće dodati grupu.",
    "Unable to delete group." : "Nemoguće izbrisati grupu.",
    "You need to set your user email before being able to send test emails." : "Prije nego li ste u mogućnosti slati testnu email trebate postaviti svoj korisnički email.",
    "Invalid mail address" : "Nevažeća adresa e-pošte",
    "Unable to create user." : "Nemoguće kreirati korisnika",
    "Unable to delete user." : "Nemoguće izbrisati korisnika",
    "Unable to change full name" : "Puno ime nije moguće promijeniti",
    "Your full name has been changed." : "Vaše puno ime je promijenjeno.",
    "Forbidden" : "Zabranjeno",
    "Invalid user" : "Nevažeči korisnik",
    "Unable to change mail address" : "Nemoguće je izmjeniti adresu e-pošte",
    "Email saved" : "E-pošta je spremljena",
    "Your %s account was created" : "Vaš %s račun je kreiran",
    "Couldn't remove app." : "Nije moguće ukloniti aplikaciju.",
    "Couldn't update app." : "Ažuriranje aplikacije nije moguće.",
    "Add trusted domain" : "Dodaj pouzdanu domenu",
    "Email sent" : "E-pošta je poslana",
    "All" : "Sve",
    "Update to %s" : "Ažuriraj na %s",
    "Error while disabling app" : "Greška pri onemogućavanju aplikacije",
    "Disable" : "Onemogući",
    "Enable" : "Omogući",
    "Error while enabling app" : "Greška pri omogućavanju aplikacije",
    "Updated" : "Ažurirano",
    "Valid until {date}" : "Validno do {date}",
    "Delete" : "Izbriši",
    "Select a profile picture" : "Odaberi sliku profila",
    "Very weak password" : "Veoma slaba lozinka",
    "Weak password" : "Slaba lozinka",
    "So-so password" : "Tu-i-tamo lozinka",
    "Good password" : "Dobra lozinka",
    "Strong password" : "Jaka lozinka",
    "Groups" : "Grupe",
    "Unable to delete {objName}" : "Nije moguće izbrisati {objName}",
    "A valid group name must be provided" : "Nužno je navesti valjani naziv grupe",
    "deleted {groupName}" : "izbrisana {groupName}",
    "undo" : "poništi",
    "never" : "nikad",
    "deleted {userName}" : "izbrisan {userName}",
    "A valid username must be provided" : "Nužno je navesti valjano korisničko ime",
    "A valid password must be provided" : "Nužno je navesti valjanu lozinku",
    "A valid email must be provided" : "Nužno je navesti valjanu adresu e-pošte",
    "Documentation:" : "Dokumentacija:",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Ova aplikacija se ne može instalirati zbog slijedećih neispunjenih ovisnosti:",
    "Enable only for specific groups" : "Omogućite samo za specifične grupe",
    "Common Name" : "Opće Ime",
    "Valid until" : "Validno do",
    "Issued By" : "Izdano od",
    "Valid until %s" : "Validno do %s",
    "Forum" : "Forum",
    "None" : "Ništa",
    "Login" : "Prijava",
    "Plain" : "Čisti tekst",
    "NT LAN Manager" : "NT LAN menedžer",
    "Send mode" : "Način rada za slanje",
    "Encryption" : "Šifriranje",
    "From address" : "S adrese",
    "mail" : "pošta",
    "Authentication method" : "Metoda autentifikacije",
    "Authentication required" : "Potrebna autentifikacija",
    "Server address" : "Adresa servera",
    "Port" : "Priključak",
    "Credentials" : "Vjerodajnice",
    "SMTP Username" : "SMTP Korisničko ime",
    "SMTP Password" : "SMPT Lozinka",
    "Store credentials" : "Spremi vjerodajnice",
    "Test email settings" : "Postavke za testnu e-poštu",
    "Send email" : "Pošalji e-poštu",
    "The Read-Only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "Samo-čitajuća konfiguracija je podešena. Ovo spriječava postavljanje neke konfiguracije putem web-sučelja. Nadalje, datoteka mora biti omogućena ručnu izmjenu pri svakom ažuriranju.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Uzrok tome je vjerojatno neki ubrzivač predmemorisanja kao što je Zend OPcache ili eAccelerator.",
    "System locale can not be set to a one which supports UTF-8." : "Regionalnu šemu sustava nemoguće je postaviti na neku koja podržava UTF-8.",
    "Execute one task with each page loaded" : "Izvrši jedan zadatak sa svakom učitanom stranicom",
    "Version" : "Verzija",
    "Sharing" : "Dijeljenje",
    "Allow apps to use the Share API" : "Dozvoli aplikacijama korištenje Share API",
    "Allow users to share via link" : "Dozvoli korisnicima dijeljenje putem veze",
    "Allow public uploads" : "Dozvoli javno učitavanje",
    "Enforce password protection" : "Nametni zaštitu lozinke",
    "Set default expiration date" : "Postavite zadani datum isteka",
    "Expire after " : "Istek nakon",
    "days" : "dana",
    "Enforce expiration date" : "Nametni datum isteka",
    "Allow resharing" : "Dopustite ponovno dijeljenje",
    "Restrict users to only share with users in their groups" : "Ograniči korisnike na međusobno dijeljenje resursa samo s korisnicima unutar svoje grupe",
    "Exclude groups from sharing" : "Isključite grupe iz dijeljenja",
    "These groups will still be able to receive shares, but not to initiate them." : "Ove će grupe i dalje moći primati dijeljene resurse, ali ne i inicirati ih",
    "Profile picture" : "Slika profila",
    "Upload new" : "Učitaj novu",
    "Remove image" : "Ukloni sliku",
    "Cancel" : "Odustani",
    "Email" : "E-pošta",
    "Your email address" : "Vaša adresa e-pošte",
    "Language" : "Jezik",
    "Help translate" : "Pomozi prevesti",
    "Password" : "Lozinka",
    "Current password" : "Trenutna lozinka",
    "New password" : "Nova lozinka",
    "Change password" : "Promijeni lozinku",
    "Username" : "Korisničko ime",
    "Show storage location" : "Prikaži mjesto pohrane",
    "Show user backend" : "Prikaži korisničku pozadinu (backend)",
    "Show email address" : "Prikaži adresu e-pošte",
    "Send email to new user" : "Pošalji e-poštu novom korisniku",
    "E-Mail" : "E-pošta",
    "Create" : "Kreiraj",
    "Admin Recovery Password" : "Admin lozinka za oporavak",
    "Enter the recovery password in order to recover the users files during password change" : "Unesite lozinku za oporavak da biste oporavili korisničke datoteke tokom promjene lozinke",
    "Everyone" : "Svi",
    "Admins" : "Administratori",
    "Please enter storage quota (ex: \"512 MB\" or \"12 GB\")" : "Molim unesite kvotu za spremanje (npr: \"512 MB\" ili \"12 GB\")",
    "Unlimited" : "Neograničeno",
    "Other" : "Ostali",
    "Quota" : "Kvota",
    "change full name" : "promijeni puno ime",
    "set new password" : "postavi novu lozinku",
    "change email address" : "promjeni adresu e-pošte",
    "Default" : "Zadano"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");

==> nextcloud-13.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/settings/l10n/bs.js <==
OC.L10N.register(
    "settings",
    {
    "Wrong password" : "Pogrešna lozinka",
    "Saved" : "Spremljeno",
    "No user supplied" : "Nijedan korisnik nije dostavljen",
    "Unable to change password" : "Promjena lozinke nije moguća",
    "Authentication error" : "Grešna autentifikacije",
    "Wrong admin recovery password. Please check the password and try again." : "Pogrešna admin lozinka za povratak. Molim provjerite lozinku i pokušajte ponovno.",
    "Group already exists." : "Grupa već postoji.",
    "Unable to add group." : "Nemoguće dodati grupu.",
    "Unable to delete group." : "Nemoguće izbrisati grupu.",
    "You need to set your user email before being able to send test emails." : "Prije nego li ste u mogućnosti slati testnu email trebate postaviti svoj korisnički email.",
    "Invalid mail address" : "Nevažeća adresa e-pošte",
    "Unable to create user." : "Nemoguće kreirati korisnika",
    "Unable to delete user." : "Nemoguće izbrisati korisnika",
    "Unable to change full name" : "Puno ime nije moguće promijeniti",
    "Your full name has been changed." : "Vaše puno ime je promijenjeno.",
    "Forbidden" : "Zabranjeno",
    "Invalid user" : "Nevažeči korisnik",
    "Unable to change mail address" : "Nemoguće je izmjeniti adresu e-pošte",
    "Email saved" : "E-pošta je spremljena",
    "Your %s account was created" : "Vaš %s račun je kreiran",
    "Couldn't remove app." : "Nije moguće ukloniti aplikaciju.",
    "Couldn't update app." : "Ažuriranje aplikacije nije moguće.",
    "Email sent" : "E-pošta je poslana",
    "All" : "Sve",
    "Update to %s" : "Ažuriraj na %s",
    "Error while disabling app" : "Greška pri onemogućavanju aplikacije",
    "Disable" : "Onemogući",
    "Enable" : "Omogući",
    "Error while enabling app" : "Greška pri omogućavanju aplikacije",
    "Updated" : "Ažurirano",
    "Valid until {date}" : "Validno do {date}",
    "Delete" : "Izbriši",
    "Select a profile picture" : "Odaberi sliku profila",
    "Very weak password" : "Veoma slaba lozinka",
    "Weak password" : "Slaba lozinka",
    "So-so password" : "Tu-i-tamo lozinka",
    "Good password" : "Dobra lozinka",
    "Strong password" : "Jaka lozinka",
    "Groups" : "Grupe",
    "Unable to delete {objName}" : "Nije moguće izbrisati {objName}",
    "A valid group name must be provided" : "Nužno je navesti valjani naziv grupe",
    "deleted {groupName}" : "izbrisana {groupName}",
    "undo" : "poništi",
    "never" : "nikad",
    "deleted {userName}" : "izbrisan {userName}",
    "A valid username must be provided" : "Nužno je navesti valjano korisničko ime",
    "Documentation:" : "Dokumentacija:",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Ova aplikacija se ne može instalirati zbog slijedećih neispunjenih ovisnosti:",
    "Enable only for specific groups" : "Omogućite samo za specifične grupe",
    "Common Name" : "Opće Ime",
    "Valid until" : "Validno do",
    "Issued By" : "Izdano od",
    "Valid until %s" : "Validno do %s",
    "Forum" : "Forum",
    "None" : "Ništa",
    "Login" : "Prijava",
    "Plain" : "Čisti tekst",
    "NT LAN Manager" : "NT LAN menedžer",
    "Send mode" : "Način rada za slanje",
    "Encryption" : "Šifriranje",
    "From address" : "S adrese",
    "mail" : "pošta",
    "Authentication method" : "Metoda autentifikacije",
    "Authentication required" : "Potrebna autentifikacija",
    "Server address" : "Adresa servera",
    "Port" : "Priključak",
    "Credentials" : "Vjerodajnice",
    "SMTP Username" : "SMTP Korisničko ime",
    "SMTP Password" : "SMPT Lozinka",
    "Store credentials" : "Spremi vjerodajnice",
    "Test email settings" : "Postavke za testnu e-poštu",
    "Send email" : "Pošalji e-poštu",
    "The Read-Only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "Samo-čitajuća konfiguracija je podešena. Ovo spriječava postavljanje neke konfiguracije putem web-sučelja. Nadalje, datoteka mora biti omogućena ručnu izmjenu pri svakom ažuriranju.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Uzrok tome je vjerojatno neki ubrzivač predmemorisanja kao što je Zend OPcache ili eAccelerator.",
    "System locale can not be set to a one which supports UTF-8." : "Regionalnu šemu sustava nemoguće je postaviti na neku koja podržava UTF-8.",
    "Execute one task with each page loaded" : "Izvrši jedan zadatak sa svakom učitanom stranicom",
    "Version" : "Verzija",
    "Sharing" : "Dijeljenje",
    "Allow apps to use the Share API" : "Dozvoli aplikacijama korištenje Share API",
    "Allow users to share via link" : "Dozvoli korisnicima dijeljenje putem veze",
    "Allow public uploads" : "Dozvoli javno učitavanje",
    "Enforce password protection" : "Nametni zaštitu lozinke",
    "Set default expiration date" : "Postavite zadani datum isteka",
    "Expire after " : "Istek nakon",
    "days" : "dana",
    "Enforce expiration date" : "Nametni datum isteka",
    "Allow resharing" : "Dopustite ponovno dijeljenje",
    "Restrict users to only share with users in their groups" : "Ograniči korisnike na međusobno dijeljenje resursa samo s korisnicima unutar svoje grupe",
    "Exclude groups from sharing" : "Isključite grupe iz dijeljenja",
    "These groups will still be able to receive shares, but not to initiate them." : "Ove će grupe i dalje moći primati dijeljene resurse, ali ne i inicirati ih",
    "Profile picture" : "Slika profila",
    "Upload new" : "Učitaj novu",
    "Remove image" : "Ukloni sliku",
    "Cancel" : "Odustani",
    "Email" : "E-pošta",
    "Your email address" : "Vaša adresa e-pošte",
    "Language" : "Jezik",
    "Help translate" : "Pomozi prevesti",
    "Password" : "Lozinka",
    "Current password" : "Trenutna lozinka",
    "New password" : "Nova lozinka",
    "Change password" : "Promijeni lozinku",
    "Username" : "Korisničko ime",
    "Show storage location" : "Prikaži mjesto pohrane",
    "Show user backend" : "Prikaži korisničku pozadinu (backend)",
    "Everyone" : "Svi",
    "Admins" : "Administratori",
    "Please enter storage quota (ex: \"512 MB\" or \"12 GB\")" : "Molim unesite kvotu za spremanje (npr: \"512 MB\" ili \"12 GB\")",
    "Unlimited" : "Neograničeno",
    "Other" : "Ostali",
    "Quota" : "Kvota",
    "E-Mail" : "E-pošta",
    "Admin Recovery Password" : "Admin lozinka za oporavak",
    "Enter the recovery password in order to recover the users files during password change" : "Unesite lozinku za oporavak da biste oporavili korisničke datoteke tokom promjene lozinke",
    "change full name" : "promijeni puno ime",
    "set new password" : "postavi novu lozinku",
    "change email address" : "promjeni adresu e-pošte",
    "Default" : "Zadano",
    "Add trusted domain" : "Dodaj pouzdanu domenu",
    "A valid password must be provided" : "Nužno je navesti valjanu lozinku",
    "A valid email must be provided" : "Nužno je navesti valjanu adresu e-pošte",
    "Show email address" : "Prikaži adresu e-pošte",
    "Send email to new user" : "Pošalji e-poštu novom korisniku",
    "Create" : "Kreiraj"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
